@@ -59,7 +59,7 @@ static struct server_id *new_server_id_task(TALLOC_CTX *mem_ctx)
 		}
 	}
 
-	msg_ctx = server_messaging_context();
+	msg_ctx = global_messaging_context();
 	if (msg_ctx == NULL) {
 		return NULL;
 	}
@@ -107,17 +107,20 @@ static struct server_id *new_server_id_task(TALLOC_CTX *mem_ctx)
  * services the AD DC.  It is tested via pdbtest.
  */
 
-static NTSTATUS check_samba4_security(const struct auth_context *auth_context,
-				      void *my_private_data,
-				      TALLOC_CTX *mem_ctx,
-				      const struct auth_usersupplied_info *user_info,
-				      struct auth_serversupplied_info **server_info)
+static NTSTATUS check_samba4_security(
+	const struct auth_context *auth_context,
+	void *my_private_data,
+	TALLOC_CTX *mem_ctx,
+	const struct auth_usersupplied_info *user_info,
+	struct auth_serversupplied_info **pserver_info)
 {
 	TALLOC_CTX *frame = talloc_stackframe();
 	struct netr_SamInfo3 *info3 = NULL;
 	NTSTATUS nt_status;
 	struct auth_user_info_dc *user_info_dc;
 	struct auth4_context *auth4_context;
+	uint8_t authoritative = 1;
+	struct auth_serversupplied_info *server_info = NULL;
 
 	nt_status = make_auth4_context_s4(auth_context, mem_ctx, &auth4_context);
 	if (!NT_STATUS_IS_OK(nt_status)) {
@@ -132,13 +135,19 @@ static NTSTATUS check_samba4_security(const struct auth_context *auth_context,
 		return nt_status;
 	}
 
-	nt_status = auth_check_password(auth4_context, auth4_context, user_info, &user_info_dc);
+	nt_status = auth_check_password(auth4_context, auth4_context, user_info,
+					&user_info_dc, &authoritative);
 	if (!NT_STATUS_IS_OK(nt_status)) {
+		if (NT_STATUS_EQUAL(nt_status, NT_STATUS_NO_SUCH_USER) &&
+				    authoritative == 0)
+		{
+			nt_status = NT_STATUS_NOT_IMPLEMENTED;
+		}
 		TALLOC_FREE(auth4_context);
 		TALLOC_FREE(frame);
 		return nt_status;
 	}
-	
+
 	nt_status = auth_convert_user_info_dc_saminfo3(mem_ctx,
 						       user_info_dc,
 						       &info3);
@@ -153,17 +162,19 @@ static NTSTATUS check_samba4_security(const struct auth_context *auth_context,
 	}
 
 	if (user_info->flags & USER_INFO_INFO3_AND_NO_AUTHZ) {
-		*server_info = make_server_info(mem_ctx);
-		if (*server_info == NULL) {
+		server_info = make_server_info(mem_ctx);
+		if (server_info == NULL) {
 			nt_status = NT_STATUS_NO_MEMORY;
 			goto done;
 		}
-		(*server_info)->info3 = talloc_steal(*server_info, info3);
-
+		server_info->info3 = talloc_move(server_info, &info3);
 	} else {
-		nt_status = make_server_info_info3(mem_ctx, user_info->client.account_name,
-						   user_info->mapped.domain_name, server_info,
-						   info3);
+		nt_status = make_server_info_info3(
+			mem_ctx,
+			user_info->client.account_name,
+			user_info->mapped.domain_name,
+			&server_info,
+			info3);
 		if (!NT_STATUS_IS_OK(nt_status)) {
 			DEBUG(10, ("make_server_info_info3 failed: %s\n",
 				   nt_errstr(nt_status)));
@@ -171,6 +182,7 @@ static NTSTATUS check_samba4_security(const struct auth_context *auth_context,
 		}
 	}
 
+	*pserver_info = server_info;
 	nt_status = NT_STATUS_OK;
 
  done:
@@ -357,8 +369,8 @@ static NTSTATUS make_auth4_context_s4(const struct auth_context *auth_context,
 
 /* module initialisation */
 static NTSTATUS auth_init_samba4(struct auth_context *auth_context,
-				    const char *param,
-				    auth_methods **auth_method)
+				 const char *param,
+				 struct auth_methods **auth_method)
 {
 	struct auth_methods *result;
 
@@ -372,7 +384,6 @@ static NTSTATUS auth_init_samba4(struct auth_context *auth_context,
 	result->auth = check_samba4_security;
 	result->prepare_gensec = prepare_gensec;
 	result->make_auth4_context = make_auth4_context_s4;
-	result->flags = AUTH_METHOD_LOCAL_SAM;
 
 	if (param && *param) {
 		auth_context->forced_samba4_methods = talloc_strdup(result, param);
@@ -385,8 +396,8 @@ static NTSTATUS auth_init_samba4(struct auth_context *auth_context,
 	return NT_STATUS_OK;
 }
 
-NTSTATUS auth_samba4_init(void);
-NTSTATUS auth_samba4_init(void)
+NTSTATUS auth_samba4_init(TALLOC_CTX *mem_ctx);
+NTSTATUS auth_samba4_init(TALLOC_CTX *mem_ctx)
 {
 	smb_register_auth(AUTH_INTERFACE_VERSION, "samba4",
 			  auth_init_samba4);
